GOOF----BE-8-2.0      ] 7 4       h      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
g  api	
 	 	
g  initialize-playing-area	g  make-standard-deck	g  shuffle-deck	g  add-normal-slot	g  DECK	g  add-blank-slot	g  add-carriage-return-slot	g  deal-cards-face-up										 		g  give-status-message	g  new-game	g  set-statusbar-message	g  get-stock-no-string	g  
string-append	g  _	f  Stock left:	f   	g  number->string	g  length	 g  	get-cards	!g  empty-slot?	"g  button-pressed	#g  check-for-deal	$g  
droppable?	%g  remove-card	&g  
add-to-score!	'g  button-released	(g  	get-value	)g  get-top-card	*g  button-clicked	+g  button-double-clicked	,g  game-won	-g  get-hint	.g  game-continuable	/g  avail-pair?	0g  	hint-move	1g  get-options	2g  
apply-options	3g  timeout	4g  set-features	5g  droppable-feature	6g  
set-lambdaC 5     h     ] 4	 >  "  G  
       h  x  ] 4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>   "  G  4>  "  G  4>  "  G  4>  "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>  "  G  4>  "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>  "  G  4>  "  G  4
	>  "  G  4
>   "  G  		 C      g  filenamef  
block-ten.scm
	
							#			3			E			U			X			]			f			i			n			w			z					 		 		 	 	 	!	 	!	 	!	 	"	 	"	 	"	 	#	 	#	 	#	 	$	 	&		'		(		(	#	(	,	)	/	)	4	)	=	*	@	*	E	*	N	,	S	,	X	,	a	-	w	/	 -	x
  g  nameg  new-game CR   h      o] 45 6        g    g  filenamef  
block-ten.scm
	1
		2			2	 		
  g  nameg  give-status-message CR     h       ] 45444
5556        g  filenamef  
block-ten.scm
	4
		5				5			5		
	5	"		6			6	!		6	)		6	!		6			5	 		
  g  nameg  get-stock-no-string CR!        h      ]4 5$  C
 C          g  slot-id
		 g  	card-list		  g  filenamef  
block-ten.scm
	8
		9		
	9			:			:	 			  g  nameg  button-pressed C"R!      h   @   ]
4
5$  C4
  5$  4
5$  C
 6C        g  
start-slot
		? g  end-slot		? g  t			? g  t		(	=  g  filenamef  
block-ten.scm
	<
		=			=			>			>	!		>		"	>		#	?		(	?		;	@	%	=	@	 		?	  g  nameg  check-for-deal C#R$%#&  h   8   ]4 5$  "45$  4 5$  	6CCC          g  
start-slot
		5 g  	card-list		5 g  end-slot			5  g  filenamef  
block-ten.scm
	B
		C			C			D			C			E		)	C		/	F	 			5	  g  nameg  button-released C'R!()  h   h  s]
$  C45$  C	
454455$  C45	
$  445545CC       k    g  
start-slot
		c g  	card-list		c g  end-slot			c g  t		1	c  g  filenamef  
block-ten.scm
	H
		I		
	I		
	J			I			K		!	K		#	K		$	L		'	L		/	L		0	K		1	K		1	K		=	O		B	O		D	O		G	O		K	O		L	P		O	P		W	P		X	Q		]	Q		_	Q		`	P	 		c	  g  nameg  
droppable? C$Rh      p]C       h    g  slot-id
		  g  filenamef  
block-ten.scm
	W
 		  g  nameg  button-clicked C*R   h      w]C       o    g  slot-id
		  g  filenamef  
block-ten.scm
	Z
 		  g  nameg  button-double-clicked C+R,-    h   (   |] 4>   "  G  45 $  C6           t    g  filenamef  
block-ten.scm
	]
		^			_			_		!	`	 		!
  g  nameg  game-continuable C.R!()       h    ]45  $  "  4455	
 $ V4	5  $  "  44	55	
 $ *4	5  $  "  44	55	
 $  4	5  $  "  44	55	
 $  4	5  $  "  44	55	
 $  4	5  $  "  44	55	
 $  z4	5  $  "  44	55	
 $  N4	5  $  "  44	55	
 $  "4		5  $   C44		55	
CCCCCCCCC            g  t
		& g  t
	1	P g  t
	[	z g  t
   g  t
   g  t
   g  t
" g  t
-L g  t
Wr  	g  filenamef  
block-ten.scm
	b
		c			c			d			d		 	d		#	d		*	c		+	e		1	e		?	f		B	f		J	f		M	f		T	c		U	g		[	g		i	h		l	h		t	h		w	h		~	c			i	 	i	 	j	 	j	 	j	 	j	 	c	 	k	 	k	 	l	 	l	 	l	 	l	 	c	 	m	 	m	 	n	 	n	 	n	 	n	 	c	 	o		o		p		p		p		p	&	c	'	q	-	q	;	r	>	r	F	r	I	r	P	c	Q	s	W	s	c	t	f	t	n	t	q	t	 @	
  g  nameg  game-won C,R!/()0      h     ]
 		$  C4 5$  "  	
$   	 645$  "  ]	
44 554455$  "  144 55	
$  44 554455"  $  	 6 6          g  slot1
	  g  slot2	  g  t			) g  t		e   g  filenamef  
block-ten.scm
	v
		w				w			y	
		y			&	z	
	-	w		2	{		7	{	"	9	{			:	|		D	|			L	}		O	}	&	W	}		X	~		[	~	&	c	~		d	}		e	}		e	}		s			v		%	~		 		 		  	  	%  	  	  	%  	  	 	w	  		  	  	 &	 	  g  nameg  avail-pair? C/R/        h      ^] 	6          V    g  filenamef  
block-ten.scm
 
		 	 			
  g  nameg  get-hint C-R     h      X] C       P    g  filenamef  
block-ten.scm
 
 		
  g  nameg  get-options C1R   h      p]C       h    g  options
		  g  filenamef  
block-ten.scm
 
 		  g  nameg  
apply-options C2R   h      T] C       L    g  filenamef  
block-ten.scm
 
 		
  g  nameg  timeout C3R44i5i>  "  G  6ii"i'i*i+i.i,i-i1i2i3i$i6            g  filenamef  
block-ten.scm		
	
	1

	4
	8
2	<
\	B

N	H

	W
b	Z
	]
	b
r	v
 
k 
 
_ 
` 
 
 	
   C6 